<?php
class DoviStatSettingsPage
{
    /**
     * Holds the values to be used in the fields callbacks
     */
    private $options;

    /**
     * Start up
     */
    public function __construct()
    {
        add_action( 'admin_menu', array( $this, 'add_plugin_page' ) );
        add_action( 'admin_init', array( $this, 'page_init' ) );
    }

    /**
     * Add options page
     */
    public function add_plugin_page()
    {
        // This page will be under "Settings"
        add_options_page(
            'Settings Admin', 
            __('DOVI STATISTICS SETTINGS', 'dovi-stat'), 
            'manage_options', 
            'dovi-stat-setting-admin', 
            array( $this, 'create_admin_page' )
        );
    }

    /**
     * Options page callback
     */
    public function create_admin_page()
    {
        // Set class property
        $this->options = get_option( 'dovi_stat_options' );
        ?>
        <div class="wrap">

            <h1><?php echo __('DOVI STATISTICS', 'dovi-stat');?></h1>
            <?php
                $active_tab = isset( $_GET[ 'tab' ] ) ? $_GET[ 'tab' ] : 'settings';
            ?>
                       
            <h2 class="nav-tab-wrapper">
                <a href="?page=dovi-stat-setting-admin&tab=settings" class="nav-tab  <?php echo $active_tab == 'settings' ? 'nav-tab-active' : ''; ?>"><?php echo __('PLUGIN SETTINGS', 'dovi-stat');?></a>
                <a href="?page=dovi-stat-setting-admin&tab=hours" class="nav-tab  <?php echo $active_tab == 'hours' ? 'nav-tab-active' : ''; ?>"><?php echo __('HOURS VIEW', 'dovi-stat');?></a>
                <a href="?page=dovi-stat-setting-admin&tab=days" class="nav-tab  <?php echo $active_tab == 'days' ? 'nav-tab-active' : ''; ?>"><?php echo __('DAYS VIEW', 'dovi-stat');?></a>
                <a href="?page=dovi-stat-setting-admin&tab=countries" class="nav-tab  <?php echo $active_tab == 'countries' ? 'nav-tab-active' : ''; ?>"><?php echo __('COUNTRIES VIEW', 'dovi-stat');?></a>
                <a href="?page=dovi-stat-setting-admin&tab=pages" class="nav-tab  <?php echo $active_tab == 'pages' ? 'nav-tab-active' : ''; ?>"><?php echo __('PAGES VIEW', 'dovi-stat');?></a>
                <a href="?page=dovi-stat-setting-admin&tab=404" class="nav-tab  <?php echo $active_tab == '404' ? 'nav-tab-active' : ''; ?>"><?php echo __('ERRORS VIEW', 'dovi-stat');?></a>
            </h2>

            <?php
                switch ($active_tab){ 
                    case 'hours':
                        include(dirname(__FILE__) . '/selector.php');
                        include(dirname(__FILE__) . '/hours.php');
                        exit;

                    case 'days':
                        include(dirname(__FILE__) . '/selector.php');
                        include(dirname(__FILE__) . '/days.php');
                        exit;

                    case 'countries':
                        include(dirname(__FILE__) . '/selector.php');
                        include(dirname(__FILE__) . '/countries.php');
                        exit;

                    case 'pages':
                        include(dirname(__FILE__) . '/selector.php');
                        include(dirname(__FILE__) . '/pages.php');
                        exit;

                    case '404':
                        include(dirname(__FILE__) . '/selector.php');
                        include(dirname(__FILE__) . '/404.php');
                        exit;

                	default :
                    ?>
                        <form method="post" action="options.php">
                        <?php
                            // This prints out all hidden setting fields
                            settings_fields( 'dovi_stat_option_main' );
                            do_settings_sections( 'dovi-stat-setting-admin' );
                            submit_button();
                        ?>
                        </form>
                        <div id="delete_stat_data" style="margin-top: 20px;border-top:1px solid #444;padding-top:20px;text-align:right;">
                            <button onclick="deleteAllData();" class="button button-warning">
                            <?php echo __('Delete all statistics data', 'dovi-stat');?>
                            </button> 
                        </div>
                    <?php
                }
?>
        </div>
        <?php
    }

    /**
     * Register and add settings
     */
    public function page_init()
    {        
        register_setting(
            'dovi_stat_option_main', // Option group
            'dovi_stat_options', // Option name
            array( $this, 'sanitize' ) // Sanitize
        );

        add_settings_section(
            'dovi_stat_settings_main', // ID
            __('STATS CUSTOM SETTINGS', 'dovi-stat'), // Title
            array( $this, 'print_section_info' ), // Callback
            'dovi-stat-setting-admin' // Page
        );  

        add_settings_field(
            'stat_send_to_admins', // ID
            __('SEND TO ADMINS', 'dovi-stat'), // Title 
            array( $this, 'stat_send_to_admins_callback' ), // Callback
            'dovi-stat-setting-admin', // Page
            'dovi_stat_settings_main' // Section           
        );      

        add_settings_field(
            'stat_send_report', // ID
            __('SEND REPORT TO', 'dovi-stat'), // Title 
            array( $this, 'stat_send_report_callback' ), // Callback
            'dovi-stat-setting-admin', // Page
            'dovi_stat_settings_main' // Section           
        );      

        add_settings_field(
            'stat_delete_old_data', // ID
            __('DELETE OLD DATA', 'dovi-stat'), // Title 
            array( $this, 'stat_delete_old_data_callback' ), // Callback
            'dovi-stat-setting-admin', // Page
            'dovi_stat_settings_main' // Section           
        );      

        add_settings_field(
            'stat_days_in_report', // ID
            __('DAYS IN REPORT', 'dovi-stat'), // Title 
            array( $this, 'stat_days_in_report_callback' ), // Callback
            'dovi-stat-setting-admin', // Page
            'dovi_stat_settings_main' // Section           
        );      

        add_settings_field(
            'stat_new_visit_hour', // ID
            __('HOUR AFTER NEW VISIT', 'dovi-stat'), // Title 
            array( $this, 'stat_new_visit_hour_callback' ), // Callback
            'dovi-stat-setting-admin', // Page
            'dovi_stat_settings_main' // Section           
        );      

        add_settings_field(
            'stat_init_count', // ID
            __('COUNTER INIT', 'dovi-stat'), // Title 
            array( $this, 'stat_init_count_callback' ), // Callback
            'dovi-stat-setting-admin', // Page
            'dovi_stat_settings_main' // Section           
        );      
    }

    /**
     * Sanitize each setting field as needed
     *
     * @param array $input Contains all settings fields as array keys
     */
    public function sanitize( $input )
    {
        $new_input = array();

        if ( isset( $input['stat_send_to_admins'] ) ) {
            $new_input['stat_send_to_admins'] = 1;
        } else {
            $new_input['stat_send_to_admins'] = 0;
        }

        if ( isset( $input['stat_send_report'] ) )
            $new_input['stat_send_report'] = str_replace(' ', '', $input['stat_send_report'] );

        if ( isset( $input['stat_delete_old_data'] ) ) {
            $new_input['stat_delete_old_data'] = 1;
        } else {
            $new_input['stat_delete_old_data'] = 0;
        }

        if ( isset( $input['stat_days_in_report'] ) )
            $new_input['stat_days_in_report'] = $input['stat_days_in_report'];

        if ( isset( $input['stat_new_visit_hour'] ) )
            $new_input['stat_new_visit_hour'] = $input['stat_new_visit_hour'];

        if ( isset( $input['stat_init_count'] ) )
            $new_input['stat_init_count'] = $input['stat_init_count'];


        return $new_input;
    }

    /** 
     * Print the Section text
     */
    public function print_section_info()
    {
        print __('THIS SETTINGS VALUES ARE GLOBALLY VALIDS', 'dovi-stat');
    }

    public function stat_send_to_admins_callback()
    {
        if (isset($this->options['stat_send_to_admins']) and ($this->options['stat_send_to_admins'] == 1)) {
            $checked = ' CHECKED ';
        } else {
            $checked = '';   
        } 
        printf(
            '<input type="checkbox" id="stat_send_to_admins" name="dovi_stat_options[stat_send_to_admins]" value="1" '.$checked.' />'.
            '<br /><small>'.__('SEND AUTOMATIC REPORT TO ADMINS.', 'dovi-stat').'</small>',
            isset( $this->options['stat_send_to_admins'] ) ? esc_attr( $this->options['stat_send_to_admins']) : ''
        );
    }


    public function stat_send_report_callback()
    {
        printf(
            '<input type="text" id="stat_send_report" name="dovi_stat_options[stat_send_report]" value="%s" style="width:300px;" />' . 
            '<br /><small>'.__('SEND REPORT TO ADMINISTRATOR AND THE SET. (Comma separated list)','dovi-stat').'</small>',
            isset( $this->options['stat_send_report'] ) ? esc_attr( $this->options['stat_send_report']) : ''
        );
    }

    public function stat_delete_old_data_callback()
    {
        if (isset($this->options['stat_delete_old_data']) and ($this->options['stat_delete_old_data'] == 1)) {
            $checked = ' CHECKED ';
        } else {
            $checked = '';   
        } 
        printf(
            '<input type="checkbox" id="stat_delete_old_data" name="dovi_stat_options[stat_delete_old_data]" value="1" '.$checked.' />'.
            '<br /><small>'.__('IF CHECKED THEN DELETE OLD DATA AFTER SEND REPORT.', 'dovi-stat').'</small>',
            isset( $this->options['stat_delete_old_data'] ) ? esc_attr( $this->options['stat_delete_old_data']) : ''
        );
    }

    public function stat_days_in_report_callback()
    {
        printf(
            '<input type="number" id="stat_days_in_report" name="dovi_stat_options[stat_days_in_report]" value="%s"/>' . 
            '<br /><small>'.__('DAYS COUNT IN REPORT','dovi-stat').'</small>',
            isset( $this->options['stat_days_in_report'] ) ? esc_attr( $this->options['stat_days_in_report']) : ''
        );
    }

    public function stat_new_visit_hour_callback()
    {
        printf(
            '<input type="number" id="stat_new_visit_hour" name="dovi_stat_options[stat_new_visit_hour]" value="%s"/>' . 
            '<br /><small>'.__('ITS A NEW VISITOR FOR SO MANY HOURS','dovi-stat').'</small>',
            isset( $this->options['stat_new_visit_hour'] ) ? esc_attr( $this->options['stat_new_visit_hour']) : ''
        );
    }

    public function stat_init_count_callback()
    {
        printf(
            '<input type="number" id="stat_init_count" name="dovi_stat_options[stat_init_count]" value="%s"/>' . 
            '<br /><small>'.__('ALL VISITORS COUNTER INIT','dovi-stat').'</small>',
            isset( $this->options['stat_init_count'] ) ? esc_attr( $this->options['stat_init_count']) : ''
        );
    }
}
