<?php
/*
    Plugin Name: Dovi Statistics
    Plugin URI: http://wpdemo.dovi42.hu/statisztika/
    Description: Statistics data in WordPress page 
    Version: 2.90
    Author: Dovi 
    Author URI: http://dovi.hu
    License: Not published
*/


if ( !defined( 'ABSPATH' ) ) exit;
require_once ( dirname(__file__) . DIRECTORY_SEPARATOR . 'autoupdate.php' ); 

global $dovi_stat_id;


class DoviVisitorCounter_Widget extends WP_Widget {

    function __construct() {
        parent::__construct(
            // base ID of the widget
            'dovivistorcounter_widget',
            // name of the widget
            __('VISITOR COUNTER WIDGET', 'dovi-stat' ),
            // widget options
            array (
                'description' => __( 'THE WIDGET SHOW THE ALL VISITORS COUNT NUMBER', 'dovi-stat' )
            )
        );
    }

    function widget( $args, $instance ) {
        global $wpdb;
        extract($instance);
        extract( $args );
        
        $options = get_option('dovi_stat_options');
        $start = $options['stat_init_count'];

        $table_name = $wpdb->prefix . 'stat_users';
        $sql = 'SELECT COUNT(*) FROM ' . $table_name;
        $count = $wpdb -> get_var($sql);
        $count = $count + $start;        

		// Widget title
		if ( ! empty( $instance['title'] ) ) {
			echo $before_title;
			echo $instance['title'];
			echo $after_title;
		}

        ?>
        <div class="visitor-counter-widget">
            <div class="visitor-counter-widget-number"><?php echo number_format($count, 0, '.', ' ');?></div>
        </div>
        <?php
    }
    
	function form( $instance ) {
		$instance = wp_parse_args( ( array ) $instance, array(
			'title'          => __( 'ALL VISITORS', 'dovi-stat' )
		) );

		$title = $instance['title'];
		?>
		<p>
			<label for="<?php echo $this->get_field_id( "title" ); ?>">
				<?php _e( 'Title', 'dovi-stat' ); ?>:
				<input class="widefat" id="<?php echo $this->get_field_id( "title" ); ?>" name="<?php echo $this->get_field_name( "title" ); ?>" type="text" value="<?php echo esc_attr( $instance["title"] ); ?>" />
			</label>
		</p>
		<?php
	}
    
}

function dovi_visitor_counter_plugin_widget() {
    register_widget( 'DoviVisitorCounter_Widget' );
}
add_action( 'widgets_init', 'dovi_visitor_counter_plugin_widget' );

function dovi_stat_update()
{
	// set auto-update params
	$plugin_current_version = '2.90'; // Current version
	$plugin_remote_path     = 'http://update.dovi42.hu/dovi-stat/update.php';  
	$plugin_slug            = plugin_basename(__FILE__);
	$license_user           = get_site_url();
	$license_key            = '<optional license key>';

	if ( $license_user && $license_key && $plugin_remote_path )
	{
		new Dovi_Stat_AutoUpdate ($plugin_current_version, $plugin_remote_path, $plugin_slug, $license_user, $license_key);
	}
}
add_action('init', 'dovi_stat_update');

function load_google_scripts() {
	wp_enqueue_script('google-chart', 'https://www.gstatic.com/charts/loader.js');
	wp_enqueue_script('dovi_sparkline', plugins_url( 'dovi-stat/js/jquery.sparkline.min.js' ));

	wp_register_script('stat-admin-js', plugins_url( 'dovi-stat/js/admin.min.js' ), array('jquery'), false, true);
    wp_localize_script('stat-admin-js', 'dovi_stat_ajax_object', array( 'ajax_url' => admin_url( 'admin-ajax.php' ) ) );
	wp_enqueue_script('stat-admin-js');
    
}
add_action('admin_enqueue_scripts', 'load_google_scripts');



function dovi_stat_load_textdomain() {
    load_plugin_textdomain( 'dovi-stat', false, basename( dirname( __FILE__ ) ) . '/languages' ); 
}
add_action( 'plugins_loaded', 'dovi_stat_load_textdomain' );

// Add settings link to plugins page 
function plugin_add_dovi_stat_settings_link( $links ) {
    $settings_link = '<a href="options-general.php?page=dovi-stat-setting-admin">' . __( 'Settings' ) . '</a>';
    array_unshift( $links, $settings_link );
    $settings_link = '<a href="options-general.php?page=dovi-stat-setting-admin&tab=days">' . __( 'SEE STATISTICS DATA', 'dovi-stat' ) . '</a>';
    array_unshift( $links, $settings_link );
  	return $links;
}
$plugin = plugin_basename( __FILE__ );
add_filter( "plugin_action_links_$plugin", 'plugin_add_dovi_stat_settings_link' );

// Add Plugin options set page
if ( is_admin() ){ // admin actions
    include('admin/dovi-stat-setup.php');
    $my_settings_page = new DoviStatSettingsPage();
} else {
    // non-admin enqueues, actions, and filters
}

// Create database
register_activation_hook( __FILE__, 'dovi_stat_create_db' );
register_deactivation_hook( __FILE__, 'dovi_stat_drop_db' );
function dovi_stat_create_db() {

	global $wpdb;
	$charset_collate = $wpdb->get_charset_collate();
	$table_name_1 = $wpdb->prefix . 'stat_users';
    $table_name_2 = $wpdb->prefix . 'stat_pages';

	$sql1 = "CREATE TABLE $table_name_1 (
		`id` int(11) NOT NULL AUTO_INCREMENT,
        `ip` varchar(15),
        `session` varchar(30),
        `country` varchar(25),
		`time` datetime DEFAULT CURRENT_TIMESTAMP,
		UNIQUE KEY id (id)
	) $charset_collate;";

	$sql2 = "CREATE TABLE $table_name_2 (
		`id` int(11) NOT NULL AUTO_INCREMENT,
        `link` varchar(150),
        `title` varchar(100),
		`time` datetime DEFAULT CURRENT_TIMESTAMP,
		UNIQUE KEY id (id)
	) $charset_collate;";


	require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
	dbDelta( $sql1 );
	dbDelta( $sql2 );
    
    update_option('dovi_stat_timestamp', date('Y-m-d'), true);
}

function dovi_stat_drop_db() {
    global $wpdb;
    delete_option('dovi_stat_options');
    $wpdb->query('DROP TABLE IF EXISTS ' . $wpdb->prefix . 'stat_users');
    $wpdb->query('DROP TABLE IF EXISTS ' . $wpdb->prefix . 'stat_pages');
    
    delete_option('dovi_stat_timestamp');    
    
}

function dovi_stat_init_session() {
    
    global $dovi_stat_id;

    if (isset($_COOKIE['sessionid'])) {
        $dovi_stat_id = $_COOKIE['sessionid'];
    } else {
        $chars = str_split('0123456789ABCDEFGHIJKLMNOUPQRSTVWZY');
        $dovi_stat_id = '';
        for ($i = 1; $i <= 30; $i++) {
        	$dovi_stat_id .= $chars[rand(0, count($chars)-1)];
        }
        // A cookie 30 nap múlva jár le.
        setcookie('sessionid', $dovi_stat_id, (time() + 60 * 60 * 24 * 30), '/');
    }
}
add_action('init', 'dovi_stat_init_session');

function dovi_stat_get_IP_address()
{
    foreach (array('HTTP_CLIENT_IP',
                   'HTTP_X_FORWARDED_FOR',
                   'HTTP_X_FORWARDED',
                   'HTTP_X_CLUSTER_CLIENT_IP',
                   'HTTP_FORWARDED_FOR',
                   'HTTP_FORWARDED',
                   'REMOTE_ADDR') as $key){
        if (array_key_exists($key, $_SERVER) === true){
            foreach (explode(',', $_SERVER[$key]) as $IPaddress){
                $IPaddress = trim($IPaddress); // Just to be safe
                if (filter_var($IPaddress,
                               FILTER_VALIDATE_IP,
                               FILTER_FLAG_NO_PRIV_RANGE | FILTER_FLAG_NO_RES_RANGE)
                    !== false) {

                    return $IPaddress;
                }
            }
            return $IPaddress;
        }
    }
}

function dovi_stat_checkBot()
{
    $USER_AGENT = strtolower($_SERVER['HTTP_USER_AGENT']);
    $crawlers = array(
        'Cron call' => 'wget',
        'Google' => 'Google',
        'MSN' => 'msnbot',
        'Bing' => 'bingbot',
        'Rambler' => 'Rambler',
        'Yahoo' => 'Yahoo',
        'AbachoBOT' => 'AbachoBOT',
        'accoona' => 'Accoona',
        'AcoiRobot' => 'AcoiRobot',
        'ASPSeek' => 'ASPSeek',
        'CrocCrawler' => 'CrocCrawler',
        'Dumbot' => 'Dumbot',
        'FAST-WebCrawler' => 'FAST-WebCrawler',
        'GeonaBot' => 'GeonaBot',
        'Gigabot' => 'Gigabot',
        'Lycos spider' => 'Lycos',
        'MSRBOT' => 'MSRBOT',
        'Altavista robot' => 'Scooter',
        'AltaVista robot' => 'Altavista',
        'ID-Search Bot' => 'IDBot',
        'eStyle Bot' => 'eStyle',
        'Scrubby robot' => 'Scrubby',
        'Facebook' => 'facebookexternalhit',
        'MJ12bot' => 'MJ12bot',
        'AhrefsBot' => 'AhrefsBot',
        'SEMrushBot' => 'semrushbot',
        'DotBot' => 'dotbot',
        'GrapeshotCrawler' => 'GrapeshotCrawler'
    );
    $pattern = '/' . strtolower(implode('|',$crawlers)) .'/i';
    $matches = array();
    $numMatches = preg_match($pattern, $USER_AGENT, $matches);
    
    if($numMatches > 0) {
        return true;
    } else {
        return false;
    }
}

function dovi_stat_set_data() {
    global $dovi_stat_id, $wpdb, $wp, $options, $wp_query;
    
    if (!dovi_stat_checkBot()) {
        // User log
        $table_name = $wpdb->prefix . 'stat_users';
        // Ennyi órával később már új látogatónak számít
        $date = strftime('%Y-%m-%d %H:%M:%S', strtotime('-' . $options['stat_new_visit_hour'] . ' hour'));
        $sql = 'SELECT COUNT(*) FROM ' . $table_name . ' WHERE session="' . $dovi_stat_id . '" AND time >= "'.$date.'"';
    
        $count = $wpdb -> get_var($sql);
        if ($count < 1) {
            $wpdb->insert( $table_name, array('session' => $dovi_stat_id, 'ip' => dovi_stat_get_IP_address()));
        }
        
        $loop = 'notfound';
        if ( $wp_query->is_page ) {
            $loop = is_front_page() ? 'front' : 'page';
        } elseif ( $wp_query->is_home ) {
            $loop = 'home';
        } elseif ( $wp_query->is_single ) {
            $loop = ( $wp_query->is_attachment ) ? 'attachment' : 'single';
        } elseif ( $wp_query->is_category ) {
            $loop = 'category';
        } elseif ( $wp_query->is_tag ) {
            $loop = 'tag';
        } elseif ( $wp_query->is_tax ) {
            $loop = 'tax';
        } elseif ( $wp_query->is_archive ) {
            if ( $wp_query->is_day ) {
                $loop = 'day';
            } elseif ( $wp_query->is_month ) {
                $loop = 'month';
            } elseif ( $wp_query->is_year ) {
                $loop = 'year';
            } elseif ( $wp_query->is_author ) {
                $loop = 'author';
            } else {
                $loop = 'archive';
            }
        } elseif ( $wp_query->is_search ) {
            $loop = 'search';
        } elseif ( $wp_query->is_404 ) {
            $loop = '404';
        }

        $current_url = home_url(add_query_arg(array(), $wp->request));
        
        switch ($loop){ 
        	case 'front':
        	   $title = '&rsaquo; ' . get_the_title();
               break;

        	case 'category':
        	   $title = '['.single_cat_title('', false).']';
               break;

        	case 'tax':
        	   $title = '['.single_cat_title('', false).']';
               break;
        
        	case 'tag':
        	   $title = '{'.single_cat_title('', false).'}';
               break;

        	case 'search':
        	   $title = __('Search') . ': ' . strip_tags(get_search_query());
               break;

        	case 'home':
        	   $title = '&rsaquo; ' . get_bloginfo('name');
               break;
            
        	case '404':
        	   $title = '404';
               break;

            default:
                $title = get_the_title();
        }        

        // Pages log
        $table_name = $wpdb->prefix . 'stat_pages';
        $wpdb->insert( $table_name, array('link' => $current_url, 'title' => $title));
    }    
}
add_action('get_footer', 'dovi_stat_set_data');

function dovi_stat( $content ) {
    global $dovi_stat_id, $options; 
    
    $pluginOptions = array(
        'stat_send_to_admins' => 1,
        'stat_send_report' => '',
        'stat_delete_old_data' => 1,
        'stat_days_in_report' => 7,
        'stat_new_visit_hour' => 1,
        'stat_init_count' => 0);

    $options = get_option('dovi_stat_options');
    foreach ($pluginOptions as $key => $value) {
        if (!isset($options[$key])) {
            $options[$key] = $pluginOptions[$key];
        }
    }

    $cronData = get_option('dovi_stat_timestamp');

    if ($cronData < date('Y-m-d')) {
        
        if (($options['stat_send_to_admins'] == 1) or ($options['stat_send_report'] != '')) {
            // dovi_stat_send_mail_report();
        	wp_register_script('dovi-stat-js', plugins_url( 'dovi-stat/js/stat.min.js' ), array('jquery'), false, true);
            wp_localize_script('dovi-stat-js', 'dovi_stat_ajax_object', array( 'ajax_url' => admin_url( 'admin-ajax.php' ) ) );
        	wp_enqueue_script('dovi-stat-js');
            
        }
    }
    
    return $content;
}
add_filter( 'the_content', 'dovi_stat' );


function dovi_stat_send_mail_report() {
    
    global $wpdb;

    $pluginOptions = array(
        'stat_send_to_admins' => 1,
        'stat_send_report' => '',
        'stat_delete_old_data' => 1,
        'stat_days_in_report' => 7,
        'stat_new_visit_hour' => 1,
        'stat_init_count' => 0);

    $options = get_option('dovi_stat_options');
    foreach ($pluginOptions as $key => $value) {
        if (!isset($options[$key])) {
            $options[$key] = $pluginOptions[$key];
        }
    }


    $days = array();
    $table_name = $wpdb->prefix . 'stat_users';
    setlocale(LC_ALL, 'hu_HU.UTF-8');
    for ($i = $options['stat_days_in_report']; $i >= 1; $i--) {
        $key = strftime('%Y-%m-%d', strtotime('-' . $i . ' day'));
        $sql = 'SELECT COUNT(*) FROM ' . $table_name . ' WHERE DATE(time) = "'.$key.'"';
        $all = $wpdb -> get_var($sql);

        $sql = 'SELECT COUNT(DISTINCT(session)) FROM ' . $table_name . ' WHERE DATE(time) = "'.$key.'"';
        $unique = $wpdb -> get_var($sql);
        $days[] = array( 
                    'date'   => $key,
                    'text'   => strftime('%b %d.', strtotime($key)),
                    'all'    => $all,
                    'unique' => $unique); 
    }

    $table_name = $wpdb->prefix . 'stat_pages';
    $sql = 'SELECT `link`, `title`, COUNT(*) AS szum FROM ' . $table_name . ' WHERE DATE(time) >= "'.$days[0]['date'].'" GROUP BY `title` ORDER BY szum DESC LIMIT 10';
    $pages = $wpdb -> get_results($sql);

    $table_name = $wpdb->prefix . 'downloads';
    $sql = 'SELECT `file`, COUNT(*) AS szum FROM ' . $table_name . ' WHERE DATE(time) >= "'.$days[0]['date'].'" GROUP BY `file` ORDER BY szum DESC LIMIT 10';
    $files = $wpdb -> get_results($sql);
    if (count($files) > 0) {
        if (!class_exists('JDescription')) {
            include_once( dirname(__file__) .DIRECTORY_SEPARATOR. 'libs' .DIRECTORY_SEPARATOR. 'description.php');
        }
        
        foreach ($files as $file) {
            $desc = new JDescription(ABSPATH . $file->file, true);
            $file->title = $desc->title;
        }
    }

    if ($options['stat_delete_old_data'] == 1) {
        $table_name = $wpdb->prefix . 'stat_users';
        $sql = 'SELECT COUNT(*) FROM ' . $table_name . ' WHERE DATE(time) < "'.$days[0]['date'].'"';
        $deleted = $wpdb -> get_var($sql);
        
        $sql = 'DELETE FROM ' . $table_name . ' WHERE DATE(time) < "'.$days[0]['date'].'"';
        $wpdb->query($sql);
        
        $table_name = $wpdb->prefix . 'stat_pages';
        $sql = 'DELETE FROM ' . $table_name . ' WHERE DATE(time) < "'.$days[0]['date'].'"';
        $wpdb->query($sql);
        
        $options['stat_init_count'] = $options['stat_init_count'] + $deleted;
        update_option('dovi_stat_options', $options);
    }        


    $query = 'SELECT '.
             'round( (( data_length + index_length) /1024 /1024 ) , 2) '.
             'FROM information_schema.TABLES '.
             'WHERE table_schema = "'.$wpdb->dbname.'" AND table_name = "'.$wpdb->prefix.'stat_pages"';
    $mb1 = $wpdb -> get_var($query);
    $query = 'SELECT '.
             'round( (( data_length + index_length) /1024 /1024 ) , 2) '.
             'FROM information_schema.TABLES '.
             'WHERE table_schema = "'.$wpdb->dbname.'" AND table_name = "'.$wpdb->prefix.'stat_users"';
    $mb2 = $wpdb -> get_var($query);
    $data_sizes = $mb1 + $mb2;

    $disk_free = disk_free_space(dirname(__FILE__));

    $si_prefix = array( 'B', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB' );
    $base = 1024;
    $class = min((int)log($disk_free , $base) , count($si_prefix) - 1);
    $free = sprintf('%1.0f' , $disk_free / pow($base,$class)) . ' ' . $si_prefix[$class];
    if ($disk_free < (50 * 1024 * 1024 * 1024)) {
        $free = '<span style="color:red;font-size: 14px;"><strong>'.$free.'</strong></span>';
    }

    $body = '
        <!DOCTYPE HTML>
        <html>
            <head>
            	<meta content="text/html; charset=UTF-8" http-equiv="Content-Type" />
                <meta name="sendto" content="[TEXT5]" />
            	<title>Egy felhasználó kitöltötte a [DATA-FILE] űrlapot</title>
                <style>
                    .small {font-size: 80%;}
                    .upper {text-transform: uppercase;}
                    hr {border-top: 1px solid #888888;}
                    h1, h2, h3, a {color: #4058C2;}
                    table {font-family:Tahoma;font-size:12px;color:#2D2D2D;}
                    td {padding:2px;}
                </style>
            </head>
            <body style="background-color: #F3F3F3;color: #333333;padding:10px;">
                <div style="max-width:600px;border:1px solid #C3C3C3;background-color:#FFFFFF;font-family:Tahoma;font-size:13px;color:#2D2D2D;">
                    <div style="padding-left: 25px;padding-right: 25px;padding-bottom: 25px;">
                        <div style="text-align:center">';

    $theme = wp_get_theme();
    $theme_string = $theme->get('Name') . '<small>&nbsp;[' . $theme->get('Version') . ']</small>';

    if ($theme->get('Template') != '') {
        $theme = wp_get_theme(wp_get_theme()->get('Template'));
        $theme_string = $theme->get('Name') . '<small>&nbsp;[' . $theme->get('Version') . ']</small>&nbsp;->&nbsp;' . $theme_string;
    }
    
    $locale = get_locale();
    $locale = substr($locale, 0, 2);
    
    $updates = wp_get_update_data();

    $body .= '<h3 style="font-size:14px;text-transform:uppercase;">' . __('Statistics report', 'dovi-stat') . '</h3>'. "\r\n";
    $body .= '</div><hr style="border: 0;border-bottom: 1px solid #C3C3C3;" />'. "\r\n";
    $body .= '<div style="font-size: 11px;color:#888;">'.__('DATE PERIOD', 'dovi-stat').': '.$days[0]['text'].' - '.$days[count($days)-1]['text'].'</div>'. "\r\n";   
    $body .= '<div style="font-size: 11px;color:#888;">'.__('DATA SIZE', 'dovi-stat').': '.number_format($data_sizes, 2, '.', ' ').' MB</div>'. "\r\n";   
    $body .= '<div style="font-size: 11px;color:#888;margin-bottom:12px;">'.__('SERVER FREE SPACE', 'dovi-stat').': '.$free.'</div>'. "\r\n";   
    
    if ($updates['counts']['total'] > 0) {
        $body .= '<div style="font-size: 11px;color:#888;"><span style="color:red;">'.__('NEED UPDATE', 'dovi-stat').':</span> '.$updates['title'].'</div>'. "\r\n";   
    }
    $body .= '<div style="font-size: 11px;color:#888;">'.__('WORDPRESS VERSION', 'dovi-stat').': '.get_bloginfo('version').'<small>&nbsp;['.$locale.']</small></div>'. "\r\n";   
    $body .= '<div style="font-size: 11px;color:#888;">'.__('WORDPRESS THEME', 'dovi-stat').': '.$theme_string.'</div>'. "\r\n";   

    $stamp = date('YmdHis');
    $size   = '&chs=600x200';
    $color  = '&chco=EBEB00,3CA715&chls=3&chm=B,FEFF8A,0,1,0|B,90FF6D,1,0,0';
    $data   = array();
    $data2  = array();
    $title  = array();
    $max = 0;
    for ($i = 0; $i <= count($days)-1; $i++) {
    	if ($days[$i]['all'] > $max) { $max = $days[$i]['all']; }
    }
    for ($i = 0; $i <= count($days)-1; $i++) {
        $data[] = @round(($days[$i]['all'] / $max) * 100);
        $data2[] = @round(($days[$i]['unique'] / $max) * 100);
        $title[] = $days[$i]['text'];
    }
    $data  = '&chd=t:' . implode(',', $data) . '|' . implode(',', $data2);
    $title = '&chxt=x,y&chxl=0:|' . implode('|', $title) . '|1:|0|' . floor($max/2). '|' . $max;
    $image_link = 'http://chart.googleapis.com/chart?cht=lc' . $data . $size . $color . $title;

    $body .= '<h4>' . __('USER STATISTICS', 'dovi-stat') . '</h4>' . "\r\n";
    $body .= '<img src="'.$image_link.'" width="100%" />' . "\r\n";
    $body .= '<table width="100%" style="border:1px solid #C3C3C3;">'. "\r\n";
    $body .= '<tr><td>&nbsp;</td>'. "\r\n";
    for ($i = 0; $i <= count($days)-1; $i++) {
        $body .= '<th width="10%" align="center" style="border-bottom:1px solid #C3C3C3;">' . $days[$i]['text'] . '</th>' . "\r\n";    	
    }
    $body .= '</tr>' . "\r\n";

    $body .= '<tr><td>' . __('USERS VISITS', 'dovi-stat') . '</td>'. "\r\n";
    for ($i = 0; $i <= count($days)-1; $i++) {
        $body .= '<td width="10%" align="center">' . number_format($days[$i]['all'], 0, '.', ' ') . '</td>' . "\r\n";    	
    }
    $body .= '</tr>' . "\r\n";
    
    $body .= '<tr><td>' . __('UNIQUIE VISITORS', 'dovi-stat') . '</td>'. "\r\n";
    for ($i = 0; $i <= count($days)-1; $i++) {
        $body .= '<td width="10%" align="center">' . number_format($days[$i]['unique'], 0, '.', ' ') . '</td>' . "\r\n";    	
    }
    $body .= '</tr></table>' . "\r\n";

    $body .= '<h4>' . __('PAGE STATISTICS', 'dovi-stat') . '</h4>' . "\r\n";
    $body .= '<table width="100%" style="border:1px solid #C3C3C3;">'. "\r\n";
    for ($i = 0; $i <= count($pages)-1; $i++) {
        $body .= '<tr><td align="left"><a href="' . $pages[$i]->link . '">' . $pages[$i]->title .'</a></td>' . "\r\n" . 
                 '<td align="right">'. number_format($pages[$i]->szum, 0, '.', ' ') . '</td></tr>' . "\r\n";    	
    }
    $body .= '</table>' . "\r\n";

    if (file_exists(ABSPATH . 'wp-content' .DIRECTORY_SEPARATOR. 'plugins' .DIRECTORY_SEPARATOR. 'dovi-download' .DIRECTORY_SEPARATOR. 'dovi-download.php')) {
        $body .= '<h4>' . __('DOWNLOAD STATISTICS', 'dovi-stat') . '</h4>' . "\r\n";
        $body .= '<table width="100%" style="border:1px solid #C3C3C3;">'. "\r\n";
        if (count($files) < 1) {
            $body .= '<tr><td colspan="2" align="center">' . __('NOTHING DOWNLOAD DATA', 'dovi-stat') . '</td></tr>';            
        } else {
            for ($i = 0; $i <= count($files)-1; $i++) {
                $title = $files[$i]->title;
                if ($title == '') { $title = $files[$i]->file; }
                $body .= '<tr><td align="left"><a href="' . esc_url(home_url('/')) . $files[$i]->file . '">' . $title .'</a></td>' . "\r\n" . 
                         '<td align="right">'. number_format($files[$i]->szum, 0, '.', ' ') . '</td></tr>' . "\r\n";    	
            }
        }
        $body .= '</table>' . "\r\n";
    }

    $body .= '
            </div>
        </body>
    </html>';

    $to = array();
    if ($options['stat_send_to_admins'] == 1) {
        $admin_email = get_option( 'admin_email' );
        if (is_array($admin_email)) {
            $to = $admin_email;
        } else {
            $to[] = $admin_email;
        }
    }
    if ($options['stat_send_report'] != '') {
        $add = explode(',',$options['stat_send_report']);
        foreach ($add as $item) {
            $item = trim($item);
            if ($item != '') {
                $to[] = $item;
            }
        }
    }
    
    $headers = array('Content-Type: text/html; charset=UTF-8');    
    $subject = __('STATISTICS REPORT', 'dovi-stat') . ' [' . esc_url( home_url('/') ) . ']';
    if (count($to) > 0) {
        $result = wp_mail($to, $subject, $body, $headers, null);
        update_option('dovi_stat_timestamp', date('Y-m-d'), true);
    }
    $data = array(
        'status' => $result
    );
    echo json_encode($data);          
    wp_die();
}
add_action( 'wp_ajax_nopriv_dovi_stat_send_mail_report', 'dovi_stat_send_mail_report' );
add_action( 'wp_ajax_dovi_stat_send_mail_report', 'dovi_stat_send_mail_report' );


function dovi_stat_delete_all_data() {

    global $wpdb;
    
    $sql = 'TRUNCATE `'.$wpdb->prefix.'stat_pages`';
    $wpdb->query($sql);
    $sql = 'TRUNCATE `'.$wpdb->prefix.'stat_users`';
    $wpdb->query($sql);
        
    $data = array(
        'status' => 1
    );
    echo json_encode($data);          
    wp_die();

}
add_action( 'wp_ajax_nopriv_dovi_stat_delete_all_data', 'dovi_stat_delete_all_data' );
add_action( 'wp_ajax_dovi_stat_delete_all_data', 'dovi_stat_delete_all_data' );


add_action('wp_dashboard_setup', 'dovi_stat_my_custom_dashboard_widgets');
function dovi_stat_my_custom_dashboard_widgets() {
    global $wp_meta_boxes;
 
    wp_add_dashboard_widget('custom_help_widget', __('Top 10 pages', 'dovi-stat'), 'dovi_stat_custom_dashboard_help');
}
 
function dovi_stat_custom_dashboard_help() {
    
    global $wpdb;
    
    $from_date = date('Y-m-d', strtotime('-1 week'));
    $to_date = date('Y-m-d');

    $pages = array();
    $table_name = $wpdb->prefix . 'stat_pages';
    $where = array();
    $where[] = '(DATE(time) >= "'.$from_date.'" AND DATE(time) <= "'.$to_date.'")';
    $where = implode(' AND ', $where);

    $sql = 'SELECT `link`, `title`, COUNT(*) AS cnt FROM ' . $table_name . ' WHERE '.$where.' GROUP BY `title` ORDER BY cnt DESC LIMIT 10';
    $pages = $wpdb -> get_results($sql);
    
    
    $form_string = strftime('%Y. %B %d., %A', strtotime($from_date));
    $to_string = strftime('%Y. %B %d., %A', strtotime($to_date));
    $napok_HU   = array("vasárnap","hétfő","kedd","szerda","csütörtök","péntek","szombat");
    $napok_EN   = array("sunday","monday","tuesday","wednesday","thursday","friday","saturday");
    $form_string = str_ireplace($napok_EN, $napok_HU, $form_string);
    $to_string = str_ireplace($napok_EN, $napok_HU, $to_string);
    $honapok_HU = array("január","február","március","április","május","június","július","augusztus","szeptember","október","november","december");
    $honapok_EN = array("january","february","march","april","maj","june","july","august","september","october","november","december");
    $form_string = str_ireplace($honapok_EN, $honapok_HU, $form_string);
    $to_string = str_ireplace($honapok_EN, $honapok_HU, $to_string);
    
    ?>
    <div style="font-size: 90%;">
        <div style="display: inline-block;float:left;"><?php echo $form_string;?></div>
        <div style="display: inline-block;float:right;"><?php echo $to_string;?></div>
    </div>
    <table class="wp-list-table widefat striped posts">
        <thead>
            <tr>
                <th><?php echo __('PAGE NAME', 'dovi-stat');?></th>
                <th><?php echo __('VIEWED COUNT', 'dovi-stat');?></th>
            </tr>
        </thead>
        <tbody>
    <?php
        foreach ($pages as $page) {
            if ($page->title == '') {
                $page->title = $page->link;
            }
            echo '<tr>'.
                 '  <td align="left"><a href="'.$page->link.'" target="_blank">'.$page->title.'</a></td>'.
                 '  <td align="right">'.number_format($page->cnt, 0, '.', ' ').'</td></tr>';
        }
    ?>    
        </tbody>
        <tfoot>
        
        </tfoot>
    </table>    
    <?php
}
